@@ -6,7 +6,7 @@
 import re, os, sys
 
 def dbg(msg):
-    if "LPLTOOLKIT_DEBUG" in os.environ:
+    if "LPLTK_DEBUG" in os.environ:
         sys.stderr.write("%s\n" %(msg))
 
 def err(msg):
