@@ -2,15 +2,16 @@
 
 from bug_tasks                   import BugTasks
 from milestone                   import Milestone
+from utils                       import typecheck_Entry
 
 # DistributionSourcePackage
 #
 class DistributionSourcePackage(object):
     # __init__
     #
-    def __init__(self, service, lp_distribution):
+    def __init__(self, service, lp_distribution_source_package):
         self.__service         = service
-        self.__lp_distribution = lp_distribution
+        self.lp_source_package = typecheck_Entry(lp_distribution_source_package)
         self.__display_name    = None
         self.__name            = None
         self.__title           = None
@@ -20,7 +21,7 @@ class DistributionSourcePackage(object):
     @property
     def display_name(self):
         if self.__display_name == None:
-            self.__display_name = self.__lp_distribution.display_name
+            self.__display_name = self.lp_source_package.display_name
         return self.__display_name
 
     # name
@@ -28,7 +29,7 @@ class DistributionSourcePackage(object):
     @property
     def name(self):
         if self.__name == None:
-            self.__name = self.__lp_distribution.name
+            self.__name = self.lp_source_package.name
         return self.__name
 
     # title
@@ -36,7 +37,7 @@ class DistributionSourcePackage(object):
     @property
     def title(self):
         if self.__title == None:
-            self.__title = self.__lp_distribution.title
+            self.__title = self.lp_source_package.title
         return self.__title
 
     # searchTasks
@@ -44,7 +45,7 @@ class DistributionSourcePackage(object):
     def search_tasks(self, **params):
         if 'milestone' in params and isinstance(params['milestone'], Milestone):
             params['milestone'] = params['milestone'].raw
-        bt = BugTasks(self.__service, self.__lp_distribution.searchTasks(**params))
+        bt = BugTasks(self.__service, self.lp_source_package.searchTasks(**params))
         return bt
 
 # vi:set ts=4 sw=4 expandtab:
